The binclass package contains an assortment of functions for feature selection, model estimation, and binary classication using internal R functions, as well as tools from the glmnet and e1071 packages.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.